@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
-(* $Id$ *)
+(* $Id: gMain.ml 1347 2007-06-20 07:40:34Z guesdon $ *)
 
 open Gtk
 open GtkMain
@@ -35,12 +35,8 @@ module Grab = struct
   let get_current () = new widget (get_current ())
 end
 
-module Event = Event
-
 module Rc = Rc
 
-module Gc_custom = Gc_custom
-
 module Timeout = Glib.Timeout
 
 module Idle = Glib.Idle
