@@ -1,4 +1,26 @@
-(* $Id: glib.mli,v 1.23 2005/08/18 12:47:28 oandrieu Exp $ *)
+(**************************************************************************)
+(*                Lablgtk                                                 *)
+(*                                                                        *)
+(*    This program is free software; you can redistribute it              *)
+(*    and/or modify it under the terms of the GNU Library General         *)
+(*    Public License as published by the Free Software Foundation         *)
+(*    version 2, with the exception described in file COPYING which       *)
+(*    comes with the library.                                             *)
+(*                                                                        *)
+(*    This program is distributed in the hope that it will be useful,     *)
+(*    but WITHOUT ANY WARRANTY; without even the implied warranty of      *)
+(*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the       *)
+(*    GNU Library General Public License for more details.                *)
+(*                                                                        *)
+(*    You should have received a copy of the GNU Library General          *)
+(*    Public License along with this program; if not, write to the        *)
+(*    Free Software Foundation, Inc., 59 Temple Place, Suite 330,         *)
+(*    Boston, MA 02111-1307  USA                                          *)
+(*                                                                        *)
+(*                                                                        *)
+(**************************************************************************)
+
+(* $Id: glib.mli 1355 2007-08-08 13:17:06Z ben_99_9 $ *)
 
 (** Interface to Glib functions 
     @gtkdoc glib index *)
@@ -263,3 +285,5 @@ val get_user_data_dir : unit -> string (** @since GTK 2.6 *)
 val get_user_config_dir : unit -> string (** @since GTK 2.6 *)
 val get_system_data_dirs : unit -> string list (** @since GTK 2.6 *)
 val get_system_config_dirs : unit -> string list (** @since GTK 2.6 *)
+
+val usleep : int -> unit
