@@ -20,7 +20,7 @@
 /*                                                                        */
 /**************************************************************************/
 
-/* $Id$ */
+/* $Id: ml_gobject.c 1390 2007-11-28 05:26:18Z garrigue $ */
 #include <stdio.h>
 #include <glib.h>
 #include <glib-object.h>
@@ -29,7 +29,6 @@
 #include <caml/memory.h>
 #include <caml/callback.h>
 #include <caml/fail.h>
-#include <caml/threads.h>
 
 #include "wrappers.h"
 #include "ml_glib.h"
@@ -40,21 +39,13 @@
 
 /* gobject.h */
 
-static GQueue objects_to_unref; /* initialized to zeroes (empty queue) */
-
-CAMLprim value ml_g_object_do_unref (value unit)
-{
-  while (! g_queue_is_empty (&objects_to_unref))
-    {
-      gpointer d = g_queue_pop_tail (&objects_to_unref);
-      g_object_unref (G_OBJECT (d));
-    }
-  return Val_unit;
-}
+static gboolean ml_g_object_unref0 (gpointer p)
+{ g_object_unref((GObject*)p); return 0; }
 
 CAMLexport void ml_g_object_unref_later (GObject *p)
 {
-  g_queue_push_head (&objects_to_unref, p);
+    g_timeout_add_full(G_PRIORITY_HIGH_IDLE, 0, ml_g_object_unref0,
+                       (gpointer)(p), NULL);
 }
 
 
@@ -79,25 +70,11 @@ static GType my_g_object_get_property_type(GObject *obj, const char *prop)
 {
     GParamSpec *pspec =
         g_object_class_find_property (G_OBJECT_GET_CLASS(obj), prop);
-    if (pspec == NULL) { 
-      g_warning("LablGtk tried to access the unsupported property %s",prop); 
-      caml_invalid_argument(prop);
-      }
+    if (pspec == NULL) raise_not_found();
     return pspec->value_type;
 }
 ML_2 (my_g_object_get_property_type, GObject_val, String_val, Val_GType)
 
-static GType internal_g_object_get_property_type(GObject *obj, const char *prop)
-{
-    GParamSpec *pspec =
-        g_object_class_find_property (G_OBJECT_GET_CLASS(obj), prop);
-    if (pspec == NULL) { 
-      g_warning("LablGtk tried to access the unsupported property %s",prop);
-      return G_TYPE_INVALID;
-      }
-    return pspec->value_type;
-}
-
 
 /* gtype.h */
 
@@ -176,10 +153,10 @@ Make_Val_final_pointer_ext(GClosure, _sink , g_closure_ref_and_sink,
 static void notify_destroy(gpointer unit, GClosure *c)
 {
     // printf("release %p\n", &c->data);
-    caml_remove_global_root((value*)&c->data);
+    remove_global_root((value*)&c->data);
 }
 
-static void marshal_core (GClosure *closure, GValue *ret,
+static void marshal (GClosure *closure, GValue *ret,
                      guint nargs, const GValue *args,
                      gpointer hint, gpointer marshall_data)
 {
@@ -195,25 +172,11 @@ static void marshal_core (GClosure *closure, GValue *ret,
     CAMLreturn0;
 }
 
-static void marshal (GClosure *closure, GValue *ret,
-                     guint nargs, const GValue *args,
-                     gpointer hint, gpointer marshall_data)
-{
-    if (polling) { // https://github.com/garrigue/lablgtk/issues/141
-      caml_leave_blocking_section();
-      polling = 0;
-      marshal_core(closure, ret, nargs, args, hint, marshall_data);
-      polling = 1;
-      caml_enter_blocking_section();
-    } else
-      marshal_core(closure, ret, nargs, args, hint, marshall_data);
-}
-
 CAMLprim value ml_g_closure_new (value clos)
 {
     GClosure* closure = g_closure_new_simple(sizeof(GClosure), (gpointer)clos);
     // printf("register %p\n", &closure->data);
-    caml_register_global_root((value*)&closure->data);
+    register_global_root((value*)&closure->data);
     g_closure_add_invalidate_notifier(closure, NULL, notify_destroy);
     g_closure_set_marshal(closure, marshal);
     return Val_GClosure_sink(closure);
@@ -304,7 +267,7 @@ CAMLprim value Val_gboxed_new(GType t, gpointer p)
 
 #define DATA  (val->data[0])
 
-static value g_value_get_mlvariant (GValue *val)
+static value g_value_get_variant (GValue *val)
 {
     CAMLparam0();
     CAMLlocal1(tmp);
@@ -390,9 +353,9 @@ static value g_value_get_mlvariant (GValue *val)
     CAMLreturn(ret);
 }
 
-ML_1 (g_value_get_mlvariant, GValue_val, ID)
+ML_1 (g_value_get_variant, GValue_val, ID)
 
-static void g_value_set_mlvariant (GValue *val, value arg)
+static void g_value_set_variant (GValue *val, value arg)
 {
     value tag = Field(arg,0);
     value data = Field(arg,1);
@@ -476,7 +439,7 @@ static void g_value_set_mlvariant (GValue *val, value arg)
     return;
 }
 
-ML_2 (g_value_set_mlvariant, GValue_val, ID, Unit)
+ML_2 (g_value_set_variant, GValue_val, ID, Unit)
 
 CAMLprim value ml_g_value_get_nativeint(value arg) {
     GValue *val = GValue_val(arg);
@@ -547,7 +510,7 @@ CAMLprim value ml_g_object_new (value type, value params)
         pspec = g_object_class_find_property (class, param->name);
         if (!pspec) failwith ("Gobject.create");
         g_value_init (&param->value, pspec->value_type);
-        g_value_set_mlvariant (&param->value, Field(Field(cell,0),1));
+        g_value_set_variant (&param->value, Field(Field(cell,0),1));
         param++;
       }
     }
@@ -565,13 +528,12 @@ CAMLprim value ml_g_object_new (value type, value params)
 CAMLprim value ml_g_object_get_property_dyn (value vobj, value prop)
 {
   GObject *obj = GObject_val(vobj);
-  GType tp = internal_g_object_get_property_type(obj, String_val(prop));
+  GType tp = my_g_object_get_property_type(obj, String_val(prop));
   GValue val = {0};
   value ret;
-  if (tp == G_TYPE_INVALID) caml_invalid_argument(String_val(prop));
   g_value_init (&val, tp);
   g_object_get_property (obj, String_val(prop), &val);
-  ret = g_value_get_mlvariant (&val);
+  ret = g_value_get_variant (&val);
   g_value_unset (&val);
   return ret;
 }
@@ -579,11 +541,10 @@ CAMLprim value ml_g_object_get_property_dyn (value vobj, value prop)
 CAMLprim value ml_g_object_set_property_dyn (value vobj, value prop, value arg)
 {
   GObject *obj = GObject_val(vobj);
-  GType tp = internal_g_object_get_property_type(obj, String_val(prop));
+  GType tp = my_g_object_get_property_type(obj, String_val(prop));
   GValue val = {0};
-  if (tp == G_TYPE_INVALID) return Val_unit; /* Silently ignore this error */
   g_value_init (&val, tp);
-  g_value_set_mlvariant (&val, arg);
+  g_value_set_variant (&val, arg);
   g_object_set_property (obj, String_val(prop), &val);
   g_value_unset (&val);
   return Val_unit;
@@ -591,64 +552,6 @@ CAMLprim value ml_g_object_set_property_dyn (value vobj, value prop, value arg)
 
 /* gsignal.h */
 
-#define Copy_GSignalQuery(ml_query, ml_params, query) \
-  ml_query = alloc_small(6, 0); \
-  ml_params = caml_alloc(query->n_params, 0); \
-  Store_field(ml_query, 0, Val_int(query->signal_id)); \
-  Store_field(ml_query, 1, caml_copy_string (query->signal_name)); \
-  Store_field(ml_query, 2, caml_copy_string (g_type_name(query->itype))); \
-  Store_field(ml_query, 3, Val_int(query->signal_flags)); \
-  Store_field(ml_query, 4, caml_copy_string (g_type_name(query->return_type)));\
-  for (i = 0; i < query->n_params; i++) \
-    Store_field(ml_params, i, Val_string(g_type_name(query->param_types[i]))); \
-  Store_field(ml_query, 5, ml_params)
-
-Make_Flags_val (Signal_type_val)
-
-CAMLprim value ml_g_signal_new_me(value o_name, value o_classe, value o_signal_flags) {
-  const gchar* name = String_val(o_name);
-  GSignalFlags signal_flags = Flags_Signal_type_val(o_signal_flags);
-  GType itype = GType_val(o_classe);
-
-  guint class_offset = 0;
-  GSignalAccumulator accumulator = NULL;
-  gpointer accu_data = NULL;
-  GSignalCMarshaller marshaller = g_cclosure_marshal_VOID__POINTER;
-  GType return_type = G_TYPE_NONE;
-  guint nparams = 0;
-  g_signal_new (name, itype, signal_flags, class_offset, accumulator, accu_data,
-      marshaller, return_type, nparams);
-  return (Val_int(0));
-}
-
-CAMLprim value ml_g_signal_query(value ml_i) {
-  CAMLparam1(ml_i);
-  CAMLlocal2(ml_query, ml_query_params);
-  GSignalQuery* query;
-  guint i = Int_val(ml_i);
-
-  query = malloc(sizeof(GSignalQuery));
-  g_signal_query(i, query);
-  if (query->signal_id == 0) invalid_argument("g_signal_query");
-
-  Copy_GSignalQuery(ml_query, ml_query_params, query);
-  free(query);
-
-  CAMLreturn(ml_query);
-}
-
-CAMLprim value ml_g_signal_list_ids(value type)
-{
-    CAMLparam1(type);
-    CAMLlocal1(ret);
-    guint n_ids;
-    guint *ids;
-    ids = g_signal_list_ids(GType_val(type), &n_ids);
-    Copy_array(ret, n_ids, ids, Val_int);
-    free(ids);
-    CAMLreturn(ret);
-}
-
 ML_4 (g_signal_connect_closure, GObject_val, String_val, GClosure_val,
       Bool_val, Val_long)
 ML_2 (g_signal_handler_block, GObject_val, Long_val, Unit)
@@ -658,8 +561,8 @@ ML_2 (g_signal_handler_is_connected, GObject_val, Long_val, Val_bool)
 ML_2 (g_signal_stop_emission_by_name, GObject_val, String_val, Unit)
 CAMLprim value ml_g_signal_emit_by_name (value obj, value sig, value params)
 {
-    value ret = Val_unit;
-    CAMLparam4(obj,sig,params,ret);
+    CAMLparam3(obj,sig,params);
+    CAMLlocal1(ret);
     GObject *instance = GObject_val(obj);
     GValue *iparams = (GValue*)calloc(1 + Wosize_val(params), sizeof(GValue));
     GQuark detail = 0;
@@ -684,13 +587,13 @@ CAMLprim value ml_g_signal_emit_by_name (value obj, value sig, value params)
     for (i = 0; i < query.n_params; i++) {
         g_value_init (&iparams[i+1],
                       query.param_types[i] & ~G_SIGNAL_TYPE_STATIC_SCOPE);
-        g_value_set_mlvariant (&iparams[i+1], Field(params,i));
+        g_value_set_variant (&iparams[i+1], Field(params,i));
     }
-    g_signal_emitv (iparams, signal_id, detail,
-                    (ret == Val_unit ? 0 : GValue_val(ret)));
+    g_signal_emitv (iparams, signal_id, detail, (ret ? GValue_val(ret) : 0));
     for (i = 0; i < query.n_params + 1; i++)
         g_value_unset (iparams + i);
     free (iparams);
+    if (!ret) ret = Val_unit;
     CAMLreturn(ret);
 }
 
